if [ $# -le 1 ]; then
	echo "usage : $0 <tracefile> <duration> [<flowid> [<header>]]"
	echo "    <tracefile>   = name of the trace file to load"
	echo "    <duration>    = activity period, in seconds"
	echo "    <flowid>      = id of the flow to consider"
	echo "    <header>      = size of the headers (in bytes)"
	exit
fi

fid=${3:-1}
header=${4:-40} # En-tête TCP par défaut = 40 bits

export LC_NUMERIC="POSIX"


####################
# Débit moyen
####################

# On extrait tous les paquets correspondant au flux $fid (et qui ne sont pas des ack)
# On enlève les doublons, puis on calcule combien d'information a transité
awk '$1 == "r" && $5 != "ack" && $8 == '$fid' { print $12, $6 }' $1 | sort -k 1n,1 | uniq | \
awk '{ s += $2 } END { print "débit moyen       du flot", '$fid', ":", s * 8 / '$2' / 1000000, "Mb/s" }'
# NB : On a viré les paquets d'aquittement qui circulent dans le mauvais sens.


####################
# Débit moyen utile
####################

# On isole cette fois en fonction des segment_id, afin d'écarter les retransmissions.
# On va ensuite retrancher à chaque paquet la taille d'un header TCP.
awk '$1 == "r" && $8 == '$fid' { print $11, $6 - '$header' }' $1 | sort -k 1n,1 | uniq | \
awk '{ s += $2 } END { print "débit moyen utile du flot", '$fid', ":", s * 8 / '$2' / 1000000, "Mb/s" }'
# Attention : non-pertinent dans le cas d'un transfert CBR
