# instantiation du simulateur
set ns [new Simulator]
set outfile "out4"

# definition de la couleur 1
$ns color 1 Blue

# instantiation du fichier de traces
set file1 [open $outfile.tr w]
$ns trace-all $file1

# instantiation du fichier de traces pour NAM
set file2 [open $outfile.nam w]
$ns namtrace-all $file2

# lorsque la simulation sera terminee, cette procedure est appelee
# pour lancer automatiquement le visualisateur NAM
proc finish {} {
  global ns file1 file2 outfile
  $ns flush-trace
  close $file1
  close $file2
  exec nam $outfile.nam &
  exit 0
}

# instantiation de deux noeuds
set n0 [$ns node]
set n1 [$ns node]

# instantiation d'une ligne de communication full duplex
# entre les noeuds n0 et n1
$ns duplex-link $n0 $n1 1Mb 30ms DropTail
$ns duplex-link-op $n0 $n1 queuePos 0.5

# instantiation d'une connexion UDP
set tcp [new Agent/TCP]
$ns attach-agent $n0 $tcp
set sink [new Agent/TCPSink]
$ns attach-agent $n1 $sink

$ns connect $tcp $sink
$tcp set fid_ 1
$tcp set packetSize_ 500

# instantiation d'un trafic CBR compose de
# paquets de 500 octets, generes toutes les 5 ms
set ftp0 [new Application/FTP]
$ftp0 attach-agent $tcp

# modelisation des erreurs
set err [new ErrorModel]
$err unit pkt
$err set rate_ 0.01
$err ranvar [new RandomVariable/Uniform]
$err drop-target [new Agent/Null]
$ns link-lossmodel $err $n0 $n1

# scenario de la simulation
$ns at 1.0 "$ftp0 start"
$ns at 5.0 "$ftp0 stop"

# la simulation va durer 6 secondes
$ns at 6.0 "finish"

# lancement de la simulation
$ns run
