if [ $# -eq 0 ]; then
	echo "usage : $0 <tracefile> [<flowid>]"
	echo "    <tracefile>   = name of the trace file to load"
	echo "    <flowid>      = id of the flow to consider"
	exit
fi

fid=${2:-1}

export LC_NUMERIC="POSIX"

# RTT = délai écoulé entre le moment où on envoie un paquet (-), et
# la date à laquelle on reçoit un acquittement qui couvre ce paquet (r).
#
# Exemple : (A) envoie tcp(65) à la date t, on cherche parmi les ack(m) reçus
# après la date t, le premier qui vérifie m ≥ 65.
#
# Inconvénients :
# _ Imaginons que le segment 88 se perde.
# _ (A) continue d'envoyer des segments 89, 90 …
# _ (B) se contente de répondre « ack(87) »
# _ (A) renvoie donc le paquet 88
# _ (B) va alors répondre ack(95) (car il aura reçu par exemple les paquets 89 à 95 auparavent)
# On en déduira alors un temps trop élevé entre les événements « send(92) » et « receive_ack(95) »,
# par rapport au temps de trajet physique pour faire un aller-retour !
#
# Que dire aussi de la mesure pour ack(95) - tcp(88) ? Est-ce que l'on prend le premier paquet, ou le paquet retransmis ?
# Dans notre cas on associera toujours le dernier paquet retransmis pour le calcul du RTT.

awk 'BEGIN { source = -1; }
$8 == '$fid' && source == -1 { source = $3; }
$8 == '$fid' && $1 == "-" &&
$5 == "tcp"  && $3 == source { print $11, $2, $5 }
$8 == '$fid' && $1 == "r" &&
$5 == "ack"  && $4 == source { print $11, $2, $5 }' $1 | \
sort -k 1n,1 -k 2n,2 | uniq | \
awk 'BEGIN { cur_tcp = -1; cur_ack = -1; }
$3 == "tcp" && $1 != cur_tcp { cur_tcp = $1;
		accu += last; n += m }
$3 == "tcp" { last = $2; m = 1; }
$3 == "ack" && $1 != cur_ack { cur_ack = $1;
		sum += $2 * (n+m) - (accu + last);
		total += n+m;
		last = 0; m = 0;
		accu = 0; n = 0; }
END { print sum / total }'

# On effectue plusieurs passes :
# _ Un premier filtre qui identifie la source du flot, extrait les envois depuis cette source (-), ainsi que les réceptions d'ack (r).
# _ Un tri qui permet de regrouper les événements dans l'ordre des segments associés
# _ Une deuxième passe qui fait plusieurs choses :
#   * Retenir les dernières (last) dates d'envoi des paquets non encore acquittés (accu).
#   * Calculer le délai entre ces dates d'envoi et la date de réception du premier ack() valide (ayant un segment_id ≥ donc).
